RoundU8Buffer

Struct RoundU8Buffer 

pub struct RoundU8Buffer<const N: usize> { /* private fields */ }
Double-ended circular Buffer. Basically a fixed size std::collections::VecDeque

Implementations

Source

impl<const N: usize> RoundU8Buffer<N>

pub fn pop_n_front<const L: usize>(&mut self) -> Option<[u8; L]>

pub const fn available_capacity(&self) -> usize

Returns the free space (capacity) in this buffer.

pub fn as_ref_mut<F: FnMut(usize, &mut [u8]) -> Result<usize, BitsError>>( &mut self, func: F, ) -> Result<(), BitsError>

Provides the function with a mutable ref to the inner buffer. The function MUST return the updated “used” size of the buffer.

pub fn as_ref_used(&self) -> (&[u8], &[u8])

pub fn as_ref_mut_available(&mut self) -> &mut [u8]

pub fn append_all(&mut self, vals: &[u8]) -> Result<(), BitsError>

Appends all values into this buffer

pub fn append_some(&mut self, vals: &[u8]) -> usize

Appends some of the data into this buffer. Returns the number of bytes successfully appended - which may be less than the total available.

pub fn consume(&mut self, amt: usize)

Advances the head pointer the specified amount, up to the filled length of this buffer.

pub fn mark_some_used(&mut self, used: usize) -> Result<(), BitsError>

Marks some of the internal buffer space as used by advancing the tail pointer by the specified amount

pub fn limit(&mut self, limit: usize) -> Result<(), BitsError>

Limits the internal returned buffer to the specified amount by clipping the ‘used length’ parameter