pub trait GroupVarintRequiredLength {
// Required method
fn gvarint_length(&self) -> u8;
}Expand description
The required length to encode in the group varint format. Either 1, 2, 3, or 4 bytes.
pub trait GroupVarintRequiredLength {
// Required method
fn gvarint_length(&self) -> u8;
}The required length to encode in the group varint format. Either 1, 2, 3, or 4 bytes.