TempDirPath

Struct TempDirPath 

pub struct TempDirPath { /* private fields */ }
Available on crate feature std only.

Implementations

Source

impl TempDirPath

pub fn new<T: AsRef<Path>>(path: T) -> Self

pub fn get_path(&self) -> &PathBuf

Returns the temporary path.

pub fn new_temp_dir() -> Result<Self, Error>

Creates a new temporary directory that will be removed upon dropping of this object with the default prefix of .tmpirx_ and then a random UUID.

pub fn new_temp_dir_prefixed(prefix: &str) -> Result<Self, Error>

Creates a new temporary directory that will be removed upon dropping of this object with the provided prefix and then a random UUID.

pub fn new_temp_file(&self) -> Result<TempFilePath, Error>

Creates a new temporary file within this directory and returns the path to that file.