pub struct TempFilePath { /* private fields */ }Available on crate feature
std only.Implementations
Sourceimpl TempFilePath
impl TempFilePath
pub fn new<T: AsRef<Path>>(path: T) -> Self
Sourcepub fn new_tempfile() -> Result<Self, Error>
pub fn new_tempfile() -> Result<Self, Error>
Creates a new temporary file with the default prefix of .tmpirxf_
that will be deleted when this object is dropped.
Sourcepub fn new_tempfile_prefixed(prefix: &str) -> Result<Self, Error>
pub fn new_tempfile_prefixed(prefix: &str) -> Result<Self, Error>
Creates a new temporary file with the provided prefix that will be deleted when this object is dropped.
pub fn open(&self, opts: &OpenOptions) -> Result<File, Error>
pub fn open_write_buffered( &self, opts: &OpenOptions, ) -> Result<BufWriter<File>, Error>
pub fn open_read_buffered( &self, opts: &OpenOptions, ) -> Result<BufReader<File>, Error>