macro_rules! cfg_docs {
($($item:item)*) => { ... };
}Expand description
Use for things that are only valid for documentation generation
macro_rules! cfg_docs {
($($item:item)*) => { ... };
}Use for things that are only valid for documentation generation