Struct irox_tools::read::ReadCounting
source · pub struct ReadCounting<T: Read> { /* private fields */ }Expand description
Wraps the reader, providing a convenient way to count the number of bytes read from the underlying impl.
Implementations
sourceimpl<T: Read> ReadCounting<T>
impl<T: Read> ReadCounting<T>
pub fn new(reader: T) -> Self
sourcepub fn get_read_count(&self) -> u64
pub fn get_read_count(&self) -> u64
Returns the number of bytes read to this point.