Eventual

Struct Eventual 

pub struct Eventual<T> { /* private fields */ }
Available on crate feature std only.
Represents a computation result that may eventually appear. Semantically equivalent to a Future, but doesn’t necessarily require an Async ecosystem around it.

Implementations

Source

impl<T> Eventual<T>

pub fn new_loaded(val: T) -> Self

Creates a new already completed task with the specified value

pub fn set(&self, val: Option<T>)

Sets the completion status of this task. Some becomes EventualStatus::Complete, None becomes EventualStatus::CompleteEmpty

pub fn set_shared(&self, val: Arc<T>)

Sets the completed status to EventualStatus::Complete using the specified value.

pub fn get(&self) -> EventualStatus<Arc<T>>

Gets the current status of this task. This is the primary method to poll over. See the module docs for an example.

pub fn take(&self) -> Option<Arc<T>>

If the task is complete, take the Arc out of storage. Further calls to get or take will return None

pub fn start(&self)

Move the task state from NotReady or CompleteEmpty to Running. Does nothing if already complete.

pub fn is_ready(&self) -> bool

True if this task is complete with EventualStatus::CompleteEmpty or EventualStatus::Complete

pub fn is_pending(&self) -> bool

True if this task has status [EventualStatus::NotRunning] or EventualStatus::Running

pub fn block_until_ready(&self) -> EventualStatus<Arc<T>>

Blocks until this task transitions into EventualStatus::CompleteEmpty or EventualStatus::Complete. If already in this state, quick returns.