pub trait WrappingAdd {
// Required method
fn wrapping_add(&self, rhs: Self) -> Self;
}Expand description
Wrapping (modular) addition. Computes self + rhs, wrapping around at the boundary of the type.
Required Methods
Sourcefn wrapping_add(&self, rhs: Self) -> Self
fn wrapping_add(&self, rhs: Self) -> Self
Wrapping (modular) addition. Computes self + rhs, wrapping around at the boundary of the type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".