Module vec

Module vec 

Available on crate feature alloc only.
Bolt-ons for Vec and VecDeque - better displays and iteration tools

Structs

PrettyVec
This struct purely exists to implement Display and UpperHex for a borrowed Vec, whose elements implement Display or UpperHex
PrettyVecDeque
This struct purely exists to implement Display and UpperHex for a borrowed VecDeque, whose elements implement Display or UpperHex

Traits

RetainTake
The retain+take operation is exactly what it sounds like. Retain only those elements that match the predicate, but return whole owned copies of the items. For efficiency’s sake, some implementations may iterate backwards through the container.