Module irox_tools::codec

source ·
A Codec is a trait that provides encode and decode to convert to/from different byte encoding formats

Modules

Traits

  • Something that can encode or decode bytes to bytes