pub struct TempDirPath { /* private fields */ }Available on crate feature
std only.Implementations
Sourceimpl TempDirPath
impl TempDirPath
pub fn new<T: AsRef<Path>>(path: T) -> Self
Sourcepub fn new_temp_dir() -> Result<Self, Error>
pub fn new_temp_dir() -> Result<Self, Error>
Creates a new temporary directory that will be removed upon dropping
of this object with the default prefix of .tmpirx_ and then a
random UUID.
Sourcepub fn new_temp_dir_prefixed(prefix: &str) -> Result<Self, Error>
pub fn new_temp_dir_prefixed(prefix: &str) -> Result<Self, Error>
Creates a new temporary directory that will be removed upon dropping of this object with the provided prefix and then a random UUID.
Sourcepub fn new_temp_file(&self) -> Result<TempFilePath, Error>
pub fn new_temp_file(&self) -> Result<TempFilePath, Error>
Creates a new temporary file within this directory and returns the path to that file.