Available on crate feature
alloc only.Structs
- Pretty
Vec - This struct purely exists to implement
DisplayandUpperHexfor a borrowed Vec, whose elements implementDisplayorUpperHex - Pretty
VecDeque - This struct purely exists to implement
DisplayandUpperHexfor a borrowed VecDeque, whose elements implementDisplayorUpperHex
Traits
- Retain
Take - The
retain+takeoperation is exactly what it sounds like. Retain only those elements that match the predicate, but return whole owned copies of the items. For efficiency’s sake, some implementations may iterate backwards through the container.