Module irox_tools::vec

source ·

Structs

Traits

  • The retain+take operation is exactly what it sounds like. Retain only those elements that match the predicate, but return whole owned copies of the items. For efficiency’s sake, some implementations may iterate backwards through the container.