Module irox_tools::vec
source · Structs
- This struct purely exists to implement ‘Display’ for a borrowed vec, whose elements implement
Display
Traits
- The
retain+takeoperation is exactly what it sounds like. Retain only those elements that match the predicate, but return whole owned copies of the items. For efficiency’s sake, some implementations may iterate backwards through the container.